
#ifndef __gpdf_marshal_MARSHAL_H__
#define __gpdf_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:VOID (gpdf-marshal.list:1) */
#define gpdf_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:INT (gpdf-marshal.list:2) */
#define gpdf_marshal_VOID__INT	g_cclosure_marshal_VOID__INT

/* VOID:DOUBLE (gpdf-marshal.list:3) */
#define gpdf_marshal_VOID__DOUBLE	g_cclosure_marshal_VOID__DOUBLE

/* VOID:POINTER (gpdf-marshal.list:4) */
#define gpdf_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER

G_END_DECLS

#endif /* __gpdf_marshal_MARSHAL_H__ */

